@@ -34,25 +34,22 @@ Rcpp::List gaussian_mcmc(const Rcpp::List model_,
   switch (model_type) {
   case 0: {
     ssm_mlg model(model_, seed);
-    mcmc_run.mcmc_gaussian(model, end_ram);
+    mcmc_run.mcmc_gaussian(model, end_ram, 
+      model_["update_fn"], model_["prior_fn"]);
     
     switch (output_type) {
     case 1: {
-      if (n_threads > 1) {
-      mcmc_run.state_posterior2(model, n_threads); //sample states
-    } else {
-      mcmc_run.state_posterior(model, n_threads); //sample states
-    }
-    
-    return Rcpp::List::create(Rcpp::Named("alpha") = mcmc_run.alpha_storage,
-      Rcpp::Named("theta") = mcmc_run.theta_storage.t(),
-      Rcpp::Named("counts") = mcmc_run.count_storage,
-      Rcpp::Named("acceptance_rate") = mcmc_run.acceptance_rate,
-      Rcpp::Named("S") = mcmc_run.S,  Rcpp::Named("posterior") = mcmc_run.posterior_storage);
+      mcmc_run.state_posterior(model, n_threads, model_["update_fn"]); //sample states
+      
+      return Rcpp::List::create(Rcpp::Named("alpha") = mcmc_run.alpha_storage,
+        Rcpp::Named("theta") = mcmc_run.theta_storage.t(),
+        Rcpp::Named("counts") = mcmc_run.count_storage,
+        Rcpp::Named("acceptance_rate") = mcmc_run.acceptance_rate,
+        Rcpp::Named("S") = mcmc_run.S,  Rcpp::Named("posterior") = mcmc_run.posterior_storage);
     } break;
     case 2: {
       //summary
-      mcmc_run.state_summary(model);
+      mcmc_run.state_summary(model, model_["update_fn"]);
       return Rcpp::List::create(Rcpp::Named("theta") = mcmc_run.theta_storage.t(),
         Rcpp::Named("alphahat") = mcmc_run.alphahat.t(), Rcpp::Named("Vt") = mcmc_run.Vt,
         Rcpp::Named("counts") = mcmc_run.count_storage,
@@ -70,24 +67,23 @@ Rcpp::List gaussian_mcmc(const Rcpp::List model_,
   } break;
   case 1: {
     ssm_ulg model(model_, seed);
-    mcmc_run.mcmc_gaussian(model, end_ram);
+    mcmc_run.mcmc_gaussian(model, end_ram, 
+      model_["update_fn"], model_["prior_fn"]);
     
     switch (output_type) {
     case 1: {
-      if (n_threads > 1) {
-      mcmc_run.state_posterior2(model, n_threads); //sample states
-    } else {
-      mcmc_run.state_posterior(model, n_threads); //sample states
-    }
-    return Rcpp::List::create(Rcpp::Named("alpha") = mcmc_run.alpha_storage,
-      Rcpp::Named("theta") = mcmc_run.theta_storage.t(),
-      Rcpp::Named("counts") = mcmc_run.count_storage,
-      Rcpp::Named("acceptance_rate") = mcmc_run.acceptance_rate,
-      Rcpp::Named("S") = mcmc_run.S,  Rcpp::Named("posterior") = mcmc_run.posterior_storage);
+      
+      mcmc_run.state_posterior(model, n_threads, model_["update_fn"]); //sample states
+      
+      return Rcpp::List::create(Rcpp::Named("alpha") = mcmc_run.alpha_storage,
+        Rcpp::Named("theta") = mcmc_run.theta_storage.t(),
+        Rcpp::Named("counts") = mcmc_run.count_storage,
+        Rcpp::Named("acceptance_rate") = mcmc_run.acceptance_rate,
+        Rcpp::Named("S") = mcmc_run.S,  Rcpp::Named("posterior") = mcmc_run.posterior_storage);
     } break;
     case 2: {
       //summary
-      mcmc_run.state_summary(model);
+      mcmc_run.state_summary(model, model_["update_fn"]);
       return Rcpp::List::create(Rcpp::Named("theta") = mcmc_run.theta_storage.t(),
         Rcpp::Named("alphahat") = mcmc_run.alphahat.t(), Rcpp::Named("Vt") = mcmc_run.Vt,
         Rcpp::Named("counts") = mcmc_run.count_storage,
@@ -188,17 +184,20 @@ Rcpp::List nongaussian_pm_mcmc(const Rcpp::List model_,
     arma::mat y = Rcpp::as<arma::mat>(model_["y"]);
     n = y.n_rows;
   }
+  
   mcmc mcmc_run(iter, burnin, thin, n, m,
     target_acceptance, gamma, S, output_type);
   
   switch (model_type) {
   case 0: {
     ssm_mng model(model_, seed);
-    mcmc_run.pm_mcmc(model, sampling_method, nsim, end_ram);
+    mcmc_run.pm_mcmc(model, sampling_method, nsim, end_ram, 
+      model_["update_fn"], model_["prior_fn"]);
   } break;
   case 1: {
     ssm_ung model(model_, seed);
-    mcmc_run.pm_mcmc(model, sampling_method, nsim, end_ram);
+    mcmc_run.pm_mcmc(model, sampling_method, nsim, end_ram, 
+      model_["update_fn"], model_["prior_fn"]);
   } break;
   case 2: {
     bsm_ng model(model_, seed);
@@ -270,11 +269,13 @@ Rcpp::List nongaussian_da_mcmc(const Rcpp::List model_,
   switch (model_type) {
   case 0: {
     ssm_mng model(model_, seed);
-    mcmc_run.da_mcmc(model, sampling_method, nsim, end_ram);
+    mcmc_run.da_mcmc(model, sampling_method, nsim, end_ram, 
+      model_["update_fn"], model_["prior_fn"]);
   } break;
   case 1: {
     ssm_ung model(model_, seed);
-    mcmc_run.da_mcmc(model, sampling_method, nsim, end_ram);
+    mcmc_run.da_mcmc(model, sampling_method, nsim, end_ram, 
+      model_["update_fn"], model_["prior_fn"]);
   } break;
   case 2: {
     bsm_ng model(model_, seed);
@@ -346,9 +347,9 @@ Rcpp::List nongaussian_is_mcmc(const Rcpp::List model_,
     n = y.n_rows;
     p = y.n_cols;
   }
-  
   approx_mcmc mcmc_run(iter, burnin, thin, n, m, p,
-    target_acceptance, gamma, S, output_type);
+    target_acceptance, gamma, S, output_type, true);
+  
   if (nsim <= 1) {
     mcmc_run.alpha_storage.zeros();
     mcmc_run.weight_storage.ones();
@@ -358,97 +359,68 @@ Rcpp::List nongaussian_is_mcmc(const Rcpp::List model_,
   switch (model_type) {
   case 0: {
     ssm_mng model(model_, seed);
-    mcmc_run.amcmc(model, 1, end_ram);
+    mcmc_run.amcmc(model, 1, end_ram,
+      model_["update_fn"], model_["prior_fn"]);
     if(approx) {
       if(output_type == 1) {
-        if (n_threads > 1) {
-          mcmc_run.approx_state_posterior2(model, n_threads);
-        } else {
-          mcmc_run.approx_state_posterior(model, n_threads);
-        }
+        mcmc_run.approx_state_posterior(model, n_threads, model_["update_fn"]);
+        
       } else {
         if(output_type == 2) {
-          mcmc_run.approx_state_summary(model);
+          mcmc_run.approx_state_summary(model, model_["update_fn"]);
         }
       }
     } else {
       if(is_type == 3) {
         mcmc_run.expand();
       }
-      if (n_threads > 1) {
-        switch (sampling_method) {
-          case 1:
-            mcmc_run.is_correction_psi2(model, nsim, is_type, n_threads);
-            break;
-          case 2:
-            mcmc_run.is_correction_bsf2(model, nsim, is_type, n_threads);
-            break;
-          case 3:
-            mcmc_run.is_correction_spdk2(model, nsim, is_type, n_threads);
-            break;
-          }
-      } else {
-        switch (sampling_method) {
-          case 1:
-            mcmc_run.is_correction_psi(model, nsim, is_type, n_threads);
-          break;
-          case 2:
-            mcmc_run.is_correction_bsf(model, nsim, is_type, n_threads);
-          break;
-          case 3:
-            mcmc_run.is_correction_spdk(model, nsim, is_type, n_threads);
-          break;
-        }
+      
+      switch (sampling_method) {
+      case 1:
+        mcmc_run.is_correction_psi(model, nsim, is_type, n_threads, model_["update_fn"]);
+        break;
+      case 2:
+        mcmc_run.is_correction_bsf(model, nsim, is_type, n_threads, model_["update_fn"]);
+        break;
+      case 3:
+        mcmc_run.is_correction_spdk(model, nsim, is_type, n_threads, model_["update_fn"]);
+        break;
       }
+      
     } 
   } break;
   case 1: {
     ssm_ung model(model_, seed);
-    mcmc_run.amcmc(model, 1, end_ram);
+    mcmc_run.amcmc(model, 1, end_ram, model_["update_fn"], model_["prior_fn"]);
     if(approx) {
       if(output_type == 1) {
-        if (n_threads > 1) {
-          mcmc_run.approx_state_posterior2(model, n_threads);
-        } else {
-          mcmc_run.approx_state_posterior(model, n_threads);
-        }
+        mcmc_run.approx_state_posterior(model, n_threads, model_["update_fn"]);
       } else {
         if(output_type == 2) {
-          mcmc_run.approx_state_summary(model);
+          mcmc_run.approx_state_summary(model, model_["update_fn"]);
         }
       }
     } else {
       if(is_type == 3) {
         mcmc_run.expand();
       }
-      if (n_threads > 1) {
-        switch (sampling_method) {
-          case 1:
-            mcmc_run.is_correction_psi2(model, nsim, is_type, n_threads);
-          break;
-          case 2:
-            mcmc_run.is_correction_bsf2(model, nsim, is_type, n_threads);
-          break;
-          case 3:
-            mcmc_run.is_correction_spdk2(model, nsim, is_type, n_threads);
-          break;
-        }
-      } else {
-        switch (sampling_method) {
-          case 1:
-            mcmc_run.is_correction_psi(model, nsim, is_type, n_threads);
-          break;
-          case 2:
-            mcmc_run.is_correction_bsf(model, nsim, is_type, n_threads);
-          break;
-          case 3:
-            mcmc_run.is_correction_spdk(model, nsim, is_type, n_threads);
-          break;
-        }
+      
+      switch (sampling_method) {
+      case 1:
+        mcmc_run.is_correction_psi(model, nsim, is_type, n_threads, model_["update_fn"]);
+        break;
+      case 2:
+        mcmc_run.is_correction_bsf(model, nsim, is_type, n_threads, model_["update_fn"]);
+        break;
+      case 3:
+        mcmc_run.is_correction_spdk(model, nsim, is_type, n_threads, model_["update_fn"]);
+        break;
       }
+      
     } 
   } break;
   case 2: {
+    
     bsm_ng model(model_, seed);
     mcmc_run.amcmc(model, 1, end_ram);
     if(approx) {
@@ -585,8 +557,7 @@ Rcpp::List nonlinear_pm_mcmc(const arma::mat& y, SEXP Z, SEXP H,
   const bool end_ram, const unsigned int n_threads,
   const unsigned int max_iter, const double conv_tol,
   const unsigned int sampling_method, const unsigned int iekf_iter,
-  const unsigned int output_type,
-  const Rcpp::Function update_fn, const Rcpp::Function prior_fn) {
+  const unsigned int output_type) {
   
   
   Rcpp::XPtr<nvec_fnPtr> xpfun_Z(Z);
@@ -601,7 +572,7 @@ Rcpp::List nonlinear_pm_mcmc(const arma::mat& y, SEXP Z, SEXP H,
   
   ssm_nlg model(y, *xpfun_Z, *xpfun_H, *xpfun_T, *xpfun_R, *xpfun_Zg, *xpfun_Tg,
     *xpfun_a1, *xpfun_P1,  theta, *xpfun_prior, known_params, known_tv_params, n_states, n_etas,
-    time_varying, update_fn, prior_fn, seed);
+    time_varying, seed);
   
   mcmc mcmc_run(iter, burnin, thin, model.n,
     model.m, target_acceptance, gamma, S, output_type);
@@ -646,8 +617,7 @@ Rcpp::List nonlinear_da_mcmc(const arma::mat& y, SEXP Z, SEXP H,
   const bool end_ram, const unsigned int n_threads,
   const unsigned int max_iter, const double conv_tol,
   const unsigned int sampling_method, const unsigned int iekf_iter,
-  const unsigned int output_type,
-  const Rcpp::Function update_fn, const Rcpp::Function prior_fn) {
+  const unsigned int output_type) {
   
   
   Rcpp::XPtr<nvec_fnPtr> xpfun_Z(Z);
@@ -662,7 +632,7 @@ Rcpp::List nonlinear_da_mcmc(const arma::mat& y, SEXP Z, SEXP H,
   
   ssm_nlg model(y, *xpfun_Z, *xpfun_H, *xpfun_T, *xpfun_R, *xpfun_Zg, *xpfun_Tg,
     *xpfun_a1, *xpfun_P1,  theta, *xpfun_prior, known_params, known_tv_params, n_states, n_etas,
-    time_varying, update_fn, prior_fn, seed);
+    time_varying, seed);
   
   mcmc mcmc_run(iter, burnin, thin, model.n,
     model.m, target_acceptance, gamma, S, output_type);
@@ -706,8 +676,7 @@ Rcpp::List nonlinear_ekf_mcmc(const arma::mat& y, SEXP Z, SEXP H,
   const unsigned int burnin, const unsigned int thin,
   const double gamma, const double target_acceptance, const arma::mat S,
   const bool end_ram, const unsigned int n_threads,
-  const unsigned int iekf_iter, const unsigned int output_type,
-  const Rcpp::Function update_fn, const Rcpp::Function prior_fn) {
+  const unsigned int iekf_iter, const unsigned int output_type) {
   
   
   Rcpp::XPtr<nvec_fnPtr> xpfun_Z(Z);
@@ -722,7 +691,7 @@ Rcpp::List nonlinear_ekf_mcmc(const arma::mat& y, SEXP Z, SEXP H,
   
   ssm_nlg model(y, *xpfun_Z, *xpfun_H, *xpfun_T, *xpfun_R, *xpfun_Zg, *xpfun_Tg,
     *xpfun_a1, *xpfun_P1,  theta, *xpfun_prior, known_params, known_tv_params, n_states, n_etas,
-    time_varying, update_fn, prior_fn, seed);
+    time_varying, seed);
   
   approx_mcmc mcmc_run(iter, burnin, thin, model.n,
     model.m, model.m, target_acceptance, gamma, S, output_type, false);
@@ -773,7 +742,6 @@ Rcpp::List nonlinear_is_mcmc(const arma::mat& y, SEXP Z, SEXP H,
   const unsigned int sampling_method, const unsigned int max_iter,
   const double conv_tol, const unsigned int iekf_iter,
   const unsigned int output_type,
-  const Rcpp::Function update_fn, const Rcpp::Function prior_fn,
   const bool approx) {
   
   Rcpp::XPtr<nvec_fnPtr> xpfun_Z(Z);
@@ -785,16 +753,15 @@ Rcpp::List nonlinear_is_mcmc(const arma::mat& y, SEXP Z, SEXP H,
   Rcpp::XPtr<a1_fnPtr> xpfun_a1(a1);
   Rcpp::XPtr<P1_fnPtr> xpfun_P1(P1);
   Rcpp::XPtr<prior_fnPtr> xpfun_prior(log_prior_pdf);
-  
+
   ssm_nlg model(y, *xpfun_Z, *xpfun_H, *xpfun_T, *xpfun_R, *xpfun_Zg, *xpfun_Tg,
     *xpfun_a1, *xpfun_P1,  theta, *xpfun_prior, known_params, known_tv_params, n_states, n_etas,
-    time_varying, update_fn, prior_fn, seed, iekf_iter, max_iter, conv_tol);
-  
+    time_varying, seed, iekf_iter, max_iter, conv_tol);
+
   approx_mcmc mcmc_run(iter, burnin, thin, model.n,
     model.m, model.m, target_acceptance, gamma, S, output_type);
-  
+
   mcmc_run.amcmc(model, sampling_method, end_ram);
-  
   if(approx) {
     if(output_type == 1) {
       mcmc_run.approx_state_posterior(model, n_threads);
