@@ -3,6 +3,8 @@
 
 #include "model_ssm_ulg.h"
 
+extern Rcpp::Function default_prior_fn;
+
 class ar1_lg: public ssm_ulg {
   
 public:
@@ -11,8 +13,9 @@ public:
   
   // update model given the parameters theta
   void update_model(const arma::vec& new_theta);
+  void update_model(const arma::vec& new_theta, const Rcpp::Function update_fn);
   
-  double log_prior_pdf(const arma::vec& x)  const;
+  double log_prior_pdf(const arma::vec& x, const Rcpp::Function prior_fn = default_prior_fn)  const;
   
 private:
   const arma::uvec prior_distributions;
